document.addEventListener('DOMContentLoaded', () => {
    const ctx = document.getElementById('lossChart').getContext('2d');
    let chart;

    // Initialize chart
    function initChart() {
        chart = new Chart(ctx, {
            type: 'line',
            data: {
                labels: [],
                datasets: [{
                    label: 'Training Loss',
                    data: [],
                    borderColor: '#3498db',
                    tension: 0.4
                }]
            },
            options: {
                responsive: true,
                scales: {
                    y: {
                        beginAtZero: true
                    }
                }
            }
        });
    }

    // Update metrics display
    function updateMetrics(metrics) {
        document.getElementById('aucMetric').textContent = metrics.auc.toFixed(4);
        document.getElementById('ksMetric').textContent = metrics.ks.toFixed(4);
        document.getElementById('logLossMetric').textContent = metrics.logLoss.toFixed(4);
    }

    // Training simulation
    function simulateTraining() {
        const epochs = parseInt(document.getElementById('epochs').value);
        const lossData = [];
        let currentEpoch = 0;

        // Reset chart
        chart.data.labels = [];
        chart.data.datasets[0].data = [];

        const trainingInterval = setInterval(() => {
            if (currentEpoch >= epochs) {
                clearInterval(trainingInterval);
                // Simulate final metrics
                updateMetrics({
                    auc: 0.85 + Math.random() * 0.1,
                    ks: 0.75 + Math.random() * 0.1,
                    logLoss: 0.2 + Math.random() * 0.1
                });
                return;
            }

            // Simulate loss value
            const loss = Math.exp(-currentEpoch/20) * (1 + Math.random() * 0.2);
            lossData.push(loss);

            // Update chart
            chart.data.labels.push(currentEpoch + 1);
            chart.data.datasets[0].data.push(loss);
            chart.update();

            currentEpoch++;
        }, 100);
    }

    // Initialize chart on load
    initChart();

    // Train button event listener
    document.getElementById('trainButton').addEventListener('click', () => {
        simulateTraining();
    });

    // Parameter input validation
    document.querySelectorAll('input[type="number"]').forEach(input => {
        input.addEventListener('change', (e) => {
            const value = parseFloat(e.target.value);
            const min = parseFloat(e.target.min);
            const max = parseFloat(e.target.max);
            
            if (value < min) e.target.value = min;
            if (value > max) e.target.value = max;
        });
    });
});
